==> accounts_management-0.1.6.gem: app/controllers/accounts_management/ledgers/ledger_entry_headers_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Ledgers::LedgerEntryHeadersController < AccountsManagementController
    # GET /ledgers/ledger_entry_headers
    # GET /ledgers/ledger_entry_headers.json
    def index
      @ledgers_ledger_entry_headers = Ledgers::LedgerEntryHeader.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @ledgers_ledger_entry_headers }
      end
    end

    # GET /ledgers/ledger_entry_headers/1
    # GET /ledgers/ledger_entry_headers/1.json
    def show
      @ledgers_ledger_entry_header = Ledgers::LedgerEntryHeader.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @ledgers_ledger_entry_header }
      end
    end

    # GET /ledgers/ledger_entry_headers/new
    # GET /ledgers/ledger_entry_headers/new.json
    def new
      @ledgers_ledger_entry_header = Ledgers::LedgerEntryHeader.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @ledgers_ledger_entry_header }
      end
    end

    # GET /ledgers/ledger_entry_headers/1/edit
    def edit
      @ledgers_ledger_entry_header = Ledgers::LedgerEntryHeader.find(params[:id])
    end

    # POST /ledgers/ledger_entry_headers
    # POST /ledgers/ledger_entry_headers.json
    def create
      @ledgers_ledger_entry_header = Ledgers::LedgerEntryHeader.new(params[:ledgers_ledger_entry_header])

      respond_to do |format|
        if @ledgers_ledger_entry_header.save
          format.html { redirect_to @ledgers_ledger_entry_header, :notice => 'Ledger entry header was successfully created.' }
          format.json { render :json => @ledgers_ledger_entry_header, :status => :created, :location => @ledgers_ledger_entry_header }
        else
          format.html { render :action => "new" }
          format.json { render :json => @ledgers_ledger_entry_header.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /ledgers/ledger_entry_headers/1
    # PUT /ledgers/ledger_entry_headers/1.json
    def update
      @ledgers_ledger_entry_header = Ledgers::LedgerEntryHeader.find(params[:id])

      respond_to do |format|
        if @ledgers_ledger_entry_header.update_attributes(params[:ledgers_ledger_entry_header])
          format.html { redirect_to @ledgers_ledger_entry_header, :notice => 'Ledger entry header was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @ledgers_ledger_entry_header.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /ledgers/ledger_entry_headers/1
    # DELETE /ledgers/ledger_entry_headers/1.json
    def destroy
      @ledgers_ledger_entry_header = Ledgers::LedgerEntryHeader.find(params[:id])
      @ledgers_ledger_entry_header.destroy

      respond_to do |format|
        format.html { redirect_to ledgers_ledger_entry_headers_url }
        format.json { head :no_content }
      end
    end
  end
end

==> accounts_management-0.1.7.gem: app/controllers/accounts_management/ledgers/ledger_entry_headers_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Ledgers::LedgerEntryHeadersController < AccountsManagementController
    # GET /ledgers/ledger_entry_headers
    # GET /ledgers/ledger_entry_headers.json
    def index
      @ledgers_ledger_entry_headers = Ledgers::LedgerEntryHeader.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @ledgers_ledger_entry_headers }
      end
    end

    # GET /ledgers/ledger_entry_headers/1
    # GET /ledgers/ledger_entry_headers/1.json
    def show
      @ledgers_ledger_entry_header = Ledgers::LedgerEntryHeader.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @ledgers_ledger_entry_header }
      end
    end

    # GET /ledgers/ledger_entry_headers/new
    # GET /ledgers/ledger_entry_headers/new.json
    def new
      @ledgers_ledger_entry_header = Ledgers::LedgerEntryHeader.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @ledgers_ledger_entry_header }
      end
    end

    # GET /ledgers/ledger_entry_headers/1/edit
    def edit
      @ledgers_ledger_entry_header = Ledgers::LedgerEntryHeader.find(params[:id])
    end

    # POST /ledgers/ledger_entry_headers
    # POST /ledgers/ledger_entry_headers.json
    def create
      @ledgers_ledger_entry_header = Ledgers::LedgerEntryHeader.new(params[:ledgers_ledger_entry_header])

      respond_to do |format|
        if @ledgers_ledger_entry_header.save
          format.html { redirect_to @ledgers_ledger_entry_header, notice: 'Ledger entry header was successfully created.' }
          format.json { render json: @ledgers_ledger_entry_header, status: :created, location: @ledgers_ledger_entry_header }
        else
          format.html { render action: "new" }
          format.json { render json: @ledgers_ledger_entry_header.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /ledgers/ledger_entry_headers/1
    # PUT /ledgers/ledger_entry_headers/1.json
    def update
      @ledgers_ledger_entry_header = Ledgers::LedgerEntryHeader.find(params[:id])

      respond_to do |format|
        if @ledgers_ledger_entry_header.update_attributes(params[:ledgers_ledger_entry_header])
          format.html { redirect_to @ledgers_ledger_entry_header, notice: 'Ledger entry header was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @ledgers_ledger_entry_header.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /ledgers/ledger_entry_headers/1
    # DELETE /ledgers/ledger_entry_headers/1.json
    def destroy
      @ledgers_ledger_entry_header = Ledgers::LedgerEntryHeader.find(params[:id])
      @ledgers_ledger_entry_header.destroy

      respond_to do |format|
        format.html { redirect_to ledgers_ledger_entry_headers_url }
        format.json { head :no_content }
      end
    end
  end
end
